Module errors

Module errors 

Implementation of optional private errors for salvo and client errors for reqwest.

Structs

ErrorResponse
Data structure responsible for server errors.

Traits

Consider
A trait that allows you to transform any error into an ErrorResponse by assigning additional parameters.

Type Aliases

BoxDynError